@@ -157,8 +157,8 @@ async def fetch_status_async(
 
 @retry(
     retry=retry_if_exception_type(httpx.HTTPError),
-    wait=wait_exponential(multiplier=1, min=1, max=8),
-    stop=stop_after_attempt(4),
+    wait=wait_exponential(multiplier=1, min=1, max=16),
+    stop=stop_after_attempt(5),
     before_sleep=before_sleep.before_sleep_log(logger, 10),
 )
 async def fetch_status_single_async(client, guid, url, headers):
@@ -530,7 +530,11 @@ class Batch:
             self.headers = {}
             self.date_mask = None
         logging.debug(f"{self.upload_csv=}")
-        self.df, self.schema_name = validate(self.upload_csv, self.permitted_tags)
+        self.df, self.schema = validate(self.upload_csv, self.permitted_tags)
+        self.schema_name = self.schema.__schema__.name
+        self.schema_fields = set(self.schema.to_schema().columns.keys()) | {
+            "sample_name"
+        }
         self.validation_json = build_validation_message(self.df, self.schema_name)
         batch_attrs = {
             "schema_name": self.schema_name,
@@ -538,8 +542,10 @@ class Batch:
             "samtools_path": self.samtools_path,
             "decontaminator_path": self.decontaminator_path,
         }
-        self.samples = [
-            Sample(**r, **batch_attrs)
+        self.samples = [  # Pass only schematised fields to the Sample constructor
+            Sample(
+                **dict((k, r[k]) for k in self.schema_fields if k in r), **batch_attrs
+            )
             for r in self.df.fillna("").reset_index().to_dict("records")
         ]
         self.paired = self.samples[0].paired
@@ -695,8 +701,15 @@ class Batch:
                 "gpas_sample_name",
             ],
         )
+        arbitrary_fields = [c for c in self.df.columns if c not in self.schema_fields]
+        combined_df = pd.merge(
+            df,
+            self.df[[*arbitrary_fields]],
+            left_on="local_sample_name",
+            right_index=True,
+        )
         target_path = self.out_dir / Path(self.batch_guid + ".mapping.csv")
-        df.to_csv(target_path, index=False)
+        combined_df.to_csv(target_path, index=False)
         self.mapping_path = target_path
 
     def _fetch_par(self):
